@@ -20,13 +20,22 @@ from ..structure_io import DATAReader, DATAWriter, XYZWriter, \
 
 vac_type_cluster_size_map = {'double': 2, 'triple': 3}
 
-__all__ = ['DefectGenerator', 'VacancyGenerator']
+__all__ = ['DefectGenerator', 'CrossLinkedDefectGenerator',
+           'StoneWalesDefectGenerator', 'VacancyGenerator']
 
 
 class DefectGenerator(object):
     pass
 
 
+class CrossLinkedDefectGenerator(object):
+    pass
+
+
+class StoneWalesDefectGenerator(object):
+    pass
+
+
 class VacancyGenerator(object):
     """Base class for generating vacancies in structure data.
 
