@@ -31,9 +31,6 @@ class GrapheneGenerator(Graphene, StructureGenerator):
 
     Parameters
     ----------
-    n, m : int, optional
-        Chiral indices defining the nanotube chiral vector
-        :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} + m\\mathbf{a}_{2} = (n, m)`.
     width : float
         Width of graphene sheet in **nanometers**
     length : float
@@ -59,12 +56,12 @@ class GrapheneGenerator(Graphene, StructureGenerator):
 
     Notes
     -----
-    For now, the graphene structure is generated using a
-    conventional unit cell, not the primitive unit cell.
+    The `GrapheneGenerator` class and its subclasses generate graphene with
+    either an armchair or zigzag edge using a 4-atom conventional unit cell.
+    If you want to generate graphene as an *unrolled nanotube*, see the
+    :py:class:`~sknano.nanogen.UnrolledNanotubeGenerator` class.
 
-    .. todo::
-
-       Add notes on unit cell calculation.
+    .. seealso:: :py:class:`~sknano.nanogen.UnrolledNanotubeGenerator`
 
     Examples
     --------
@@ -129,16 +126,17 @@ class GrapheneGenerator(Graphene, StructureGenerator):
 
     """
 
-    def __init__(self, n=None, m=None, width=None, length=None,
-                 edge=None, element1='C', element2='C', bond=CCbond,
+    def __init__(self, width=None, length=None, edge=None,
+                 element1='C', element2='C', bond=CCbond,
                  nlayers=1, layer_spacing=3.35, stacking_order='AB',
-                 autogen=True, with_units=False, verbose=False):
+                 autogen=True, with_units=False, units=None,
+                 verbose=False):
 
         super(GrapheneGenerator, self).__init__(
-            n=n, m=m, width=width, length=length, edge=edge,
+            width=width, length=length, edge=edge,
             element1=element1, element2=element2, bond=bond,
             nlayers=nlayers, layer_spacing=layer_spacing,
-            stacking_order=stacking_order, with_units=with_units,
+            stacking_order=stacking_order, with_units=with_units, units=units,
             verbose=verbose)
 
         if autogen:
@@ -194,8 +192,8 @@ class GrapheneGenerator(Graphene, StructureGenerator):
             layer = Atoms()
             for nx in xrange(self._Nx):
                 for ny in xrange(self._Ny):
-                    dr = np.array([nx * self._lx,
-                                   ny * self._ly,
+                    dr = np.array([nx * self._cell.x,
+                                   ny * self._cell.y,
                                    nlayer * self._layer_spacing])
                     for atom in self._unit_cell:
                         layer_atom = Atom(atom.symbol)
@@ -208,12 +206,10 @@ class GrapheneGenerator(Graphene, StructureGenerator):
             # translate layer to put its center of mass at the origin
             layer.center_CM(r_indices=[0, 1])
             if (nlayer % 2) != 0:
-                layer.translate(self._layer_shift)
+                layer.translate(self._layer_shift.components)
 
             self._structure_atoms.extend(layer.atoms)
 
-        #self.update_structure_atoms_attributes()
-
     def save_data(self, fname=None, structure_format=None, rotation_angle=-90,
                   rot_axis='x', deg2rad=True, center_CM=True):
         """Save structure data.
@@ -225,13 +221,13 @@ class GrapheneGenerator(Graphene, StructureGenerator):
         structure_format : {None, str}, optional
             chemical file format of saved structure data. Must be one of:
 
-                - xyz
-                - data
+                - `xyz`
+                - `data`
 
             If `None`, then guess based on `fname` file extension or
             default to `xyz` format.
         rotation_angle : {None, float}, optional
-            Angle of rotation
+            Angle of rotation.
         rot_axis : {'x', 'y', 'z'}, optional
             Rotation axis
         deg2rad : bool, optional
@@ -248,7 +244,7 @@ class GrapheneGenerator(Graphene, StructureGenerator):
             structure_format = default_structure_format
 
         if fname is None:
-            dimensions = '{}nmx{}nm'.format(self._Lx, self._Ly)
+            dimensions = '{}nmx{}nm'.format(self._width, self._length)
             nlayer = '{}layer'.format(self._nlayers)
             edge = 'AC' if self._edge in ('AC', 'armchair') else 'ZZ'
             atombond = '{}{}'.format(self._element1, self._element2)
@@ -291,9 +287,6 @@ class BiLayerGrapheneGenerator(GrapheneGenerator):
 
     Parameters
     ----------
-    n, m : int, optional
-        Chiral indices defining the nanotube chiral vector
-        :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} + m\\mathbf{a}_{2} = (n, m)`.
     width : float
         Width of graphene sheet in **nanometers**
     length : float
@@ -368,14 +361,14 @@ class BiLayerGrapheneGenerator(GrapheneGenerator):
 
     """
 
-    def __init__(self, n=None, m=None, width=None, length=None, edge=None,
+    def __init__(self, width=None, length=None, edge=None,
                  element1='C', element2='C', bond=CCbond,
                  layer_spacing=3.35, stacking_order='AB',
                  rotation_angle=None, deg2rad=True, autogen=True,
                  verbose=False):
 
         super(BiLayerGrapheneGenerator, self).__init__(
-            n=n, m=m, width=width, length=length, edge=edge,
+            width=width, length=length, edge=edge,
             element1=element1, element2=element2, bond=bond,
             nlayers=2, layer_spacing=layer_spacing, autogen=False,
             verbose=verbose)
