@@ -13,11 +13,7 @@ Nanotube structure generators (:mod:`sknano.nanogen._nanotube_generators`)
 
 .. todo::
 
-   Handle different units and perform unit conversions for output coordinates.
-
-.. todo::
-
-   Replace arrays with class attributes for readability.
+   Handle different units in output coordinates.
 
 """
 from __future__ import division, print_function, absolute_import
@@ -26,8 +22,6 @@ __docformat__ = 'restructuredtext'
 import copy
 #import itertools
 #import sys
-import warnings
-warnings.filterwarnings('ignore')  # to suppress the Pint UnicodeWarning
 
 #from pint import UnitRegistry
 #ureg = UnitRegistry()
@@ -44,7 +38,7 @@ from ..tools.refdata import CCbond
 from ._nanotubes import Nanotube
 from ._structure_generator import StructureGenerator
 
-__all__ = ['NanotubeGenerator', 'MWNTGenerator']
+__all__ = ['NanotubeGenerator', 'UnrolledNanotubeGenerator', 'MWNTGenerator']
 
 
 class NanotubeGenerator(Nanotube, StructureGenerator):
@@ -88,12 +82,16 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
         if `True`, automatically call
         :py:meth:`~NanotubeGenerator.generate_unit_cell`,
         followed by :py:meth:`~NanotubeGenerator.generate_structure_data`.
+    with_units : bool, optional
+        Attach `units` to physical quantities
+    units : None, optional
+        System of units to use.
     verbose : bool, optional
         if `True`, show verbose output
 
     Examples
     --------
-    First, load the :py:class:`~sknano.nanogen.NanoGenerator` class.
+    First, load the :py:class:`~sknano.nanogen.NanotubeGenerator` class.
 
     >>> from sknano.nanogen import NanotubeGenerator
 
@@ -114,9 +112,9 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
     """
 
     def __init__(self, n=int, m=int, nx=1, ny=1, nz=1,
-                 element1='C', element2='C',
-                 bond=CCbond, Lx=None, Ly=None, Lz=None,
-                 tube_length=None, fix_Lz=False,
+                 element1='C', element2='C', bond=CCbond, tube_length=None,
+                 Lx=None, Ly=None, Lz=None, fix_Lz=False,
+                 with_units=False, units=None,
                  autogen=True, verbose=False):
 
         if tube_length is not None and Lz is None:
@@ -126,7 +124,7 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
             n=n, m=m, nx=nx, ny=ny, nz=nz,
             element1=element1, element2=element2,
             bond=bond, Lx=Lx, Ly=Ly, Lz=Lz, fix_Lz=fix_Lz,
-            with_units=False, verbose=verbose)
+            with_units=False, units=units, verbose=verbose)
 
         if autogen:
             self.generate_unit_cell()
@@ -285,6 +283,266 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
             XYZWriter.write(fname=self._fname, atoms=self._structure_atoms)
 
 
+class CappedNanotubeGenerator(Nanotube, StructureGenerator):
+    u"""Class for generating capped nanotube structures."""
+    pass
+
+
+class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
+    u"""Class for generating unrolled nanotube structures.
+
+    .. versionadded:: 0.2.23
+
+    Parameters
+    ----------
+    n, m : int
+        Chiral indices defining the nanotube chiral vector
+        :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} + m\\mathbf{a}_{2} = (n, m)`.
+    nx, ny, nz : int, optional
+        Number of repeat unit cells in the :math:`x, y, z` dimensions
+    element1, element2 : {str, int}, optional
+        Element symbol or atomic number of basis
+        :py:class:`~sknano.chemistry.Atoms` 1 and 2
+    bond : float, optional
+        :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
+        nearest neighbor atoms. Must be in units of **Angstroms**.
+    Lx, Ly, Lz : float, optional
+        Length of bundle in :math:`x, y, z` dimensions in **nanometers**.
+        Overrides the :math:`n_x, n_y, n_z` cell values.
+    fix_Lz : bool, optional
+        Generate the nanotube with length as close to the specified
+        :math:`L_z` as possible. If `True`, then
+        non integer :math:`n_z` cells are permitted.
+    autogen : bool, optional
+        if `True`, automatically call
+        :py:meth:`~NanotubeGenerator.generate_unit_cell`,
+        followed by :py:meth:`~NanotubeGenerator.generate_structure_data`.
+    with_units : bool, optional
+        Attach `units` to physical quantities
+    units : None, optional
+        System of units to use.
+    verbose : bool, optional
+        if `True`, show verbose output
+
+    Notes
+    -----
+    The `UnrolledNanotubeGenerator` class generates graphene using the
+    nanotube unit cell defined by the chiral vector
+    :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} + m\\mathbf{a}_{2} = (n, m)`.
+    If you want to generate graphene with an armchair or zigzag edge using
+    `length` and `width` parameters, see the
+    :py:class:`~sknano.nanogen.GrapheneGenerator` class.
+
+    .. seealso:: :py:class:`~sknano.nanogen.GrapheneGenerator`
+
+
+    Examples
+    --------
+    First, load the :py:class:`~sknano.nanogen.UnrolledNanotubeGenerator`
+    class.
+
+    >>> from sknano.nanogen import UnrolledNanotubeGenerator
+
+    Now let's generate an unrolled :math:`\\mathbf{C}_{\\mathrm{h}} = (10, 5)`
+    SWCNT unit cell.
+
+    >>> flatswcnt = UnrolledNanotubeGenerator(n=10, m=5)
+    >>> flatswcnt.save_data()
+
+    The rendered structure looks like:
+
+    """
+
+    def __init__(self, n=int, m=int, nx=1, ny=1, nz=1,
+                 element1='C', element2='C', bond=CCbond,
+                 Lx=None, Ly=None, Lz=None, fix_Lz=False,
+                 nlayers=None, layer_spacing=None, stacking_order=None,
+                 with_units=False, units=None, autogen=True, verbose=False):
+
+        super(UnrolledNanotubeGenerator, self).__init__(
+            n=n, m=m, nx=nx, ny=ny, nz=nz,
+            element1=element1, element2=element2,
+            bond=bond, Lx=Lx, Ly=Ly, Lz=Lz, fix_Lz=fix_Lz,
+            with_units=False, units=units, verbose=verbose)
+
+        if autogen:
+            self.generate_unit_cell()
+            self.generate_structure_data()
+
+    def generate_unit_cell(self):
+        """Generate the nanotube unit cell."""
+        eps = 0.01
+        n = self._n
+        m = self._m
+        bond = self._bond
+        M = self._M
+        T = self._T
+        N = self._N
+        rt = self._rt
+        e1 = self._element1
+        e2 = self._element2
+        verbose = self._verbose
+
+        aCh = Nanotube.compute_chiral_angle(n=n, m=m, rad2deg=False)
+
+        tau = M * T / N
+        dtau = bond * np.sin(np.pi / 6 - aCh)
+
+        psi = 2 * np.pi / N
+        dpsi = bond * np.cos(np.pi / 6 - aCh) / rt
+
+        if verbose:
+            print('dpsi: {}'.format(dpsi))
+            print('dtau: {}\n'.format(dtau))
+
+        self._unit_cell = Atoms()
+
+        for i in xrange(N):
+            x1 = rt * i * psi
+            z1 = i * tau
+
+            while z1 > T - eps:
+                z1 -= T
+
+            atom1 = Atom(e1, x=x1, z=z1)
+            atom1.rezero_coords()
+
+            if verbose:
+                print('Basis Atom 1:\n{}'.format(atom1))
+
+            self._unit_cell.append(atom1)
+
+            x2 = rt * (i * psi + dpsi)
+            z2 = i * tau - dtau
+            while z2 > T - eps:
+                z2 -= T
+
+            atom2 = Atom(e2, x=x2, z=z2)
+            atom2.rezero_coords()
+
+            if verbose:
+                print('Basis Atom 2:\n{}'.format(atom2))
+
+            self._unit_cell.append(atom2)
+
+    def generate_structure_data(self):
+        """Generate structure data."""
+        self._structure_atoms = Atoms()
+        for nx in xrange(self.nx):
+            for nz in xrange(int(np.ceil(self.nz))):
+                dr = np.array([nx * self.Ch, 0.0, nz * self.T])
+                for uc_atom in self._unit_cell:
+                    nt_atom = Atom(uc_atom.symbol)
+                    nt_atom.r = uc_atom.r + dr
+                    self._structure_atoms.append(nt_atom)
+
+    def save_data(self, fname=None, structure_format=None,
+                  rotation_angle=None, rot_axis=None, deg2rad=True,
+                  center_CM=True):
+        """Save structure data.
+
+        Parameters
+        ----------
+        fname : {None, str}, optional
+            file name string
+        structure_format : {None, str}, optional
+            chemical file format of saved structure data. Must be one of:
+
+                - xyz
+                - data
+
+            If `None`, then guess based on `fname` file extension or
+            default to `xyz` format.
+        rotation_angle : {None, float}, optional
+            Angle of rotation
+        rot_axis : {'x', 'y', 'z'}, optional
+            Rotation axis
+        deg2rad : bool, optional
+            Convert `rotation_angle` from degrees to radians.
+        center_CM : bool, optional
+            Center center-of-mass on origin.
+
+        """
+        if (fname is None and structure_format not in
+                supported_structure_formats) or \
+                (fname is not None and not
+                    fname.endswith(supported_structure_formats) and
+                    structure_format not in supported_structure_formats):
+            structure_format = default_structure_format
+
+        if fname is None:
+            chirality = '{}{}f'.format('{}'.format(self._n).zfill(2),
+                                       '{}'.format(self._m).zfill(2))
+
+            nx = self.nx
+            ny = self.ny
+            fname_wordlist = None
+            if nx != 1 or ny != 1:
+                nx = ''.join(('{}'.format(self.nx),
+                              plural_word_check('cell', self.nx)))
+                ny = ''.join(('{}'.format(self.ny),
+                              plural_word_check('cell', self.ny)))
+
+                if self._assume_integer_unit_cells:
+                    nz = ''.join(('{}'.format(self.nz),
+                                  plural_word_check('cell', self.nz)))
+                else:
+                    nz = ''.join(('{:.2f}'.format(self.nz),
+                                  plural_word_check('cell', self.nz)))
+
+                cells = 'x'.join((nx, ny, nz))
+                fname_wordlist = (chirality, cells)
+            else:
+                if self._assume_integer_unit_cells:
+                    nz = ''.join(('{}'.format(self.nz),
+                                  plural_word_check('cell', self.nz)))
+                else:
+                    nz = ''.join(('{:.2f}'.format(self.nz),
+                                  plural_word_check('cell', self.nz)))
+
+                fname_wordlist = (chirality, nz)
+
+            fname = '_'.join(fname_wordlist)
+            fname += '.' + structure_format
+        else:
+            if fname.endswith(supported_structure_formats) and \
+                    structure_format is None:
+                for ext in supported_structure_formats:
+                    if fname.endswith(ext):
+                        structure_format = ext
+                        break
+            else:
+                if structure_format is None or \
+                        structure_format not in supported_structure_formats:
+                    structure_format = default_structure_format
+
+        self._fname = fname
+
+        if center_CM:
+            self._structure_atoms.center_CM()
+
+        if self._L0 is not None and self._fix_Lz:
+            self._structure_atoms.clip_bounds(
+                min_limit=-(10 * self._L0 + 0.2) / 2, r_indices=[2])
+            if center_CM:
+                self._structure_atoms.center_CM()
+            self._structure_atoms.clip_bounds(
+                max_limit=(10 * self._L0 + 0.2) / 2, r_indices=[2])
+            if center_CM:
+                self._structure_atoms.center_CM()
+
+        if rotation_angle is not None:
+            R_matrix = rotation_matrix(rotation_angle,
+                                       rot_axis=rot_axis,
+                                       deg2rad=deg2rad)
+            self._structure_atoms.rotate(R_matrix)
+
+        if structure_format == 'data':
+            DATAWriter.write(fname=self._fname, atoms=self._structure_atoms)
+        else:
+            XYZWriter.write(fname=self._fname, atoms=self._structure_atoms)
+
+
 class MWNTGenerator(NanotubeGenerator):
     u"""Class for generating single, multi-walled nanotubes.
 
@@ -316,19 +574,32 @@ class MWNTGenerator(NanotubeGenerator):
         Generate the nanotube with length as close to the specified
         :math:`L_z` as possible. If `True`, then
         non integer :math:`n_z` cells are permitted.
+    add_outer_shells : bool, optional
+        Build the MWNT by adding outer shells
+
+        .. versionadded:: 0.2.23
+
+    add_inner_shells : bool, optional
+        Build the MWNT by adding inner shells
+
+        .. versionadded:: 0.2.23
+
     max_shells : int, optional
         Maximum number of shells per MWNT.
+    max_shell_diameter : float, optional
+        Maximum shell diameter, in units of **Angstroms**.
+    min_shells : int, optional
+        Minimum number of shells per MWNT.
     min_shell_diameter : float, optional
         Minimum shell diameter, in units of **Angstroms**.
+    new_shell_type : {None, 'AC', 'ZZ', 'achiral', 'chiral'}, optional
+        If `None`, the chiralities of the new shells are constrained only
+        by their diameter and will be chosen randomly if more than one
+        candidate chirality exists. If not `None`, then the
+        `new_shell_type` will be added as a constraint.
     shell_spacing : float, optional
         Shell spacing in units of **Angstroms**. Default
         value is the van der Waals interaction distance of 3.4 Angstroms.
-    inner_shell_Ch_type : {None, 'armchair', AC', 'zigzag', 'ZZ', 'achiral',
-                           'chiral'}, optional
-        If `None`, the chiralities of the inner shells are constrained only
-        by their diameter and will be chosen randomly if more than one
-        candidate chirality exists. If not `None`, then the inner
-        shell chirality type will be added as a constraint.
     autogen : bool, optional
         if `True`, automatically call
         :py:meth:`~MWNTGenerator.generate_unit_cell`,
@@ -348,22 +619,36 @@ class MWNTGenerator(NanotubeGenerator):
     """
     def __init__(self, n=int, m=int, nx=1, ny=1, nz=1,
                  element1='C', element2='C', bond=CCbond,
-                 Lx=None, Ly=None, Lz=None, fix_Lz=False, max_shells=None,
-                 min_shell_diameter=0.0, shell_spacing=3.4,
-                 inner_shell_Ch_type=None, autogen=True, verbose=False):
+                 Lx=None, Ly=None, Lz=None, fix_Lz=False,
+                 add_inner_shells=True, add_outer_shells=False,
+                 max_shells=None, max_shell_diameter=np.inf,
+                 min_shells=None, min_shell_diameter=0.0,
+                 new_shell_type=None, shell_spacing=3.4,
+                 with_units=False, units=None, autogen=True, verbose=False):
 
         super(MWNTGenerator, self).__init__(
-            n=n, m=m, nx=nx, ny=ny, nz=nz, bond=bond, element1=element1,
-            element2=element2, Lx=Lx, Ly=Ly, Lz=Lz, fix_Lz=fix_Lz,
+            n=n, m=m, nx=nx, ny=ny, nz=nz,
+            element1=element1, element2=element2, bond=bond,
+            Lx=Lx, Ly=Ly, Lz=Lz, fix_Lz=fix_Lz,
+            with_units=with_units, units=units,
             autogen=False, verbose=verbose)
 
+        self._add_inner_shells = add_inner_shells
+        self._add_outer_shells = add_outer_shells
+        self._starting_shell_position = 'outer'
+
         self._max_shells = max_shells
         if max_shells is None:
-            self._max_shells = np.inf
+            self._max_shells = 10
+        self._max_shell_diameter = max_shell_diameter
 
+        self._min_shells = min_shells
+        if min_shells is None:
+            self._min_shells = 2
         self._min_shell_diameter = min_shell_diameter
+
+        self._new_shell_type = new_shell_type
         self._shell_spacing = shell_spacing
-        self._inner_shell_Ch_type = inner_shell_Ch_type
 
         self._Nshells_per_tube = 1
         self._Natoms_per_tube = 0
@@ -427,19 +712,17 @@ class MWNTGenerator(NanotubeGenerator):
            generating it every time.
 
         """
-        dt = []
         Ch = []
+        dt = []
         for n in xrange(0, 201):
             for m in xrange(0, 201):
                 if (n <= 2 and m <= 2):
                     continue
                 else:
-                    dt.append(Nanotube.compute_dt(n=n, m=m, bond=self._bond))
                     Ch.append((n, m))
-        dt = np.asarray(dt)
+                    dt.append(Nanotube.compute_dt(n=n, m=m, bond=self._bond))
         Ch = np.asarray(Ch)
-
-        self._min_shell_diameter = max(self._min_shell_diameter, dt.min())
+        dt = np.asarray(dt)
 
         super(MWNTGenerator, self).generate_structure_data()
 
@@ -447,40 +730,53 @@ class MWNTGenerator(NanotubeGenerator):
         self._structure_atoms = Atoms(atoms=swnt0, deepcopy=True)
         self._structure_atoms.center_CM()
 
-        Lzmin = self._Lz
-        next_dt = self._dt - 2 * self._shell_spacing
+        self._max_shell_diameter = min(self._max_shell_diameter, dt.max())
+        self._min_shell_diameter = max(self._min_shell_diameter, dt.min())
+
+        Lzmin = self.Lz
+
+        delta_dt = -2 * self._shell_spacing
+        max_dt_diff = 0.05
+
+        if self._add_outer_shells:
+            delta_dt = -delta_dt
+            self._starting_shell_position = 'inner'
+
+        next_dt = self.dt + delta_dt
         while self._Nshells_per_tube < self._max_shells and \
+                next_dt <= self._max_shell_diameter and \
                 next_dt >= self._min_shell_diameter:
 
             # get chiral indices for next_dt
             next_Ch_candidates = []
-            delta_dt = 0.05
             while len(next_Ch_candidates) == 0 and \
+                    next_dt <= self._max_shell_diameter and \
                     next_dt >= self._min_shell_diameter:
-                if self._inner_shell_Ch_type in ('AC', 'armchair'):
+
+                if self._new_shell_type in ('AC', 'armchair'):
                     next_Ch_candidates = \
                         Ch[np.where(
-                            np.logical_and(np.abs(dt - next_dt) <= delta_dt,
+                            np.logical_and(np.abs(dt - next_dt) <= max_dt_diff,
                                            Ch[:,0] == Ch[:,1]))]
-                elif self._inner_shell_Ch_type in ('ZZ', 'zigzag'):
+                elif self._new_shell_type in ('ZZ', 'zigzag'):
                     next_Ch_candidates = \
                         Ch[np.where(
-                            np.logical_and(np.abs(dt - next_dt) <= delta_dt,
+                            np.logical_and(np.abs(dt - next_dt) <= max_dt_diff,
                                            np.logical_or(Ch[:,0] == 0,
                                                          Ch[:,1] == 0)))]
-                elif self._inner_shell_Ch_type == 'achiral':
+                elif self._new_shell_type == 'achiral':
                     next_Ch_candidates = \
                         Ch[np.where(
-                            np.logical_and(np.abs(dt - next_dt) <= delta_dt,
+                            np.logical_and(np.abs(dt - next_dt) <= max_dt_diff,
                                            np.logical_or(
                                                Ch[:,0] == Ch[:,1],
                                                np.logical_or(
                                                    Ch[:,0] == 0,
                                                    Ch[:,1] == 0))))]
-                elif self._inner_shell_Ch_type == 'chiral':
+                elif self._new_shell_type == 'chiral':
                     next_Ch_candidates = \
                         Ch[np.where(
-                            np.logical_and(np.abs(dt - next_dt) <= delta_dt,
+                            np.logical_and(np.abs(dt - next_dt) <= max_dt_diff,
                                            np.logical_and(
                                                Ch[:,0] != Ch[:,1],
                                                np.logical_and(
@@ -488,10 +784,12 @@ class MWNTGenerator(NanotubeGenerator):
                                                    Ch[:,1] != 1))))]
                 else:
                     next_Ch_candidates = \
-                        Ch[np.where(np.abs(dt - next_dt) <= delta_dt)]
+                        Ch[np.where(np.abs(dt - next_dt) <= max_dt_diff)]
 
-                next_dt -= delta_dt
-                #delta_dt += 0.05
+                if self._add_outer_shells:
+                    next_dt += max_dt_diff
+                else:
+                    next_dt -= max_dt_diff
 
             if len(next_Ch_candidates) > 0:
                 n, m = next_Ch_candidates[
@@ -521,7 +819,7 @@ class MWNTGenerator(NanotubeGenerator):
                 shell.center_CM()
                 self._structure_atoms.extend(shell.atoms)
                 self._Nshells_per_tube += 1
-                next_dt -= 2 * self._shell_spacing
+                next_dt += delta_dt
             else:
                 break
 
@@ -550,8 +848,8 @@ class MWNTGenerator(NanotubeGenerator):
         structure_format : {None, str}, optional
             chemical file format of saved structure data. Must be one of:
 
-                - xyz
-                - data
+                - `xyz`
+                - `data`
 
             If `None`, then guess based on `fname` file extension or
             default to `xyz` format.
@@ -574,8 +872,9 @@ class MWNTGenerator(NanotubeGenerator):
 
         if fname is None:
             Nshells = '{}shell_mwnt'.format(self._Nshells_per_tube)
-            chirality = '{}{}_outer_Ch'.format('{}'.format(self._n).zfill(2),
-                                               '{}'.format(self._m).zfill(2))
+            chirality = '{}{}_{}_Ch'.format('{}'.format(self._n).zfill(2),
+                                            '{}'.format(self._m).zfill(2),
+                                            self._starting_shell_position)
 
             fname_wordlist = None
             if self._assume_integer_unit_cells:
