@@ -10,10 +10,6 @@ Nanotube structure tools (:mod:`sknano.nanogen._nanotubes`)
 from __future__ import division, print_function, absolute_import
 __docformat__ = 'restructuredtext'
 
-#import itertools
-import warnings
-warnings.filterwarnings('ignore')  # to suppress the Pint UnicodeWarning
-
 from fractions import gcd
 from collections import OrderedDict
 
@@ -29,29 +25,9 @@ except ImportError:
 from ..chemistry import Atom
 from ..tools.refdata import CCbond
 
-param_units = {}
-param_units['dt'] = \
-    param_units['rt'] = \
-    param_units['Ch'] = \
-    param_units['T'] = \
-    param_units['bond'] = u' \u212B'
-param_units['chiral_angle'] = u'\u00b0'
+from ._parameter_luts import param_units, param_symbols, param_strfmt
 
-param_symbols = {}
-param_symbols['t1'] = u't\u2081'
-param_symbols['t2'] = u't\u2082'
-param_symbols['chiral_angle'] = u'\u03b8c'
-
-param_strfmt = {}
-param_strfmt['Ch'] = \
-    param_strfmt['T'] = \
-    param_strfmt['dt'] = \
-    param_strfmt['rt'] = \
-    param_strfmt['chiral_angle'] = '{:.2f}'
-param_strfmt['bond'] = '{:.3f}'
-
-__all__ = ['param_units', 'param_symbols', 'param_strfmt',
-           'Nanotube', 'NanotubeBundle']
+__all__ = ['Nanotube', 'NanotubeBundle']
 
 
 class Nanotube(object):
@@ -92,6 +68,10 @@ class Nanotube(object):
 
         .. versionadded:: 0.2.6
 
+    with_units : bool, optional
+        Attach `units` to physical quantities
+    units : None, optional
+        System of units to use.
     verbose : bool, optional
         verbose output
 
@@ -166,7 +146,7 @@ class Nanotube(object):
     def __init__(self, n=int, m=int, nx=1, ny=1, nz=1, element1='C',
                  element2='C', bond=CCbond, tube_length=None,
                  Lx=None, Ly=None, Lz=None, fix_Lz=False,
-                 with_units=False, verbose=False):
+                 with_units=False, units=None, verbose=False):
 
         if tube_length is not None and Lz is None:
             Lz = tube_length
@@ -185,11 +165,11 @@ class Nanotube(object):
         self._params['M'] = {}
         self._params['R'] = {}
         self._params['bond'] = {}
+        self._params['chiral_angle'] = {}
         self._params['Ch'] = {}
         self._params['T'] = {}
         self._params['dt'] = {}
         self._params['rt'] = {}
-        self._params['chiral_angle'] = {}
         self._params['electronic_type'] = {}
 
         self._n = int(n)
@@ -202,11 +182,14 @@ class Nanotube(object):
 
         if with_units and Qty is None:
             with_units = False
-
         self._with_units = with_units
 
+        if with_units and units is None:
+            units = 'angstroms'
+        self._units = units
+
         if with_units and isinstance(bond, float):
-            self._bond = Qty(bond, 'angstroms')
+            self._bond = Qty(bond, units)
         else:
             self._bond = bond
 
@@ -227,8 +210,6 @@ class Nanotube(object):
         self._t2 = None
         self._Ch = None
         self._T = None
-        self._dt = None
-        self._rt = None
         self._chiral_angle = None
         self._N = None
         self._M = None
@@ -238,35 +219,10 @@ class Nanotube(object):
         self._Natoms = None
         self._Lz = None
         self._Natoms_per_tube = None
+        self._dt = None
+        self._rt = None
         self._electronic_type = None
 
-        try:
-            self._a = np.sqrt(3) * self._bond.magnitude
-        except AttributeError:
-            self._a = np.sqrt(3) * self._bond
-
-        self._a1 = np.zeros(2, dtype=float)
-        self._a2 = np.zeros(2, dtype=float)
-
-        self._a1[0] = self._a2[0] = np.sqrt(3) / 2 * self._a
-        self._a1[1] = 1 / 2 * self._a
-        self._a2[1] = -self._a1[1]
-
-        self._b1 = np.zeros(2, dtype=float)
-        self._b2 = np.zeros(2, dtype=float)
-
-        self._b1[0] = self._b2[0] = \
-            1 / np.sqrt(3) * 2 * np.pi / self._a
-        self._b1[1] = 2 * np.pi / self._a
-        self._b2[1] = -self._b1[1]
-
-        if with_units:
-            self._a1 = Qty(self._a1, 'angstrom')
-            self._a2 = Qty(self._a2, 'angstrom')
-
-            self._b1 = Qty(self._b1, '1/angstrom')
-            self._b2 = Qty(self._b2, '1/angstrom')
-
         self._Ntubes = 1
         self._nx = int(nx)
         self._ny = int(ny)
@@ -407,31 +363,6 @@ class Nanotube(object):
         """Element symbol of :py:class:`~sknano.chemistry.Atom` 2."""
         return self._element2
 
-    @property
-    def a(self):
-        """Length of graphene unit cell vector."""
-        return self._a
-
-    @property
-    def a1(self):
-        """:math:`a_1` unit vector."""
-        return self._a1
-
-    @property
-    def a2(self):
-        """:math:`a_2` unit vector."""
-        return self._a2
-
-    @property
-    def b1(self):
-        """:math:`b_1` reciprocal lattice vector."""
-        return self._b1
-
-    @property
-    def b2(self):
-        """:math:`b_2` reciprocal lattice vector."""
-        return self._b2
-
     @property
     def t1(self):
         """:math:`t_{1} = \\frac{2m + n}{d_{R}}`
@@ -1285,6 +1216,30 @@ class Nanotube(object):
     @classmethod
     def compute_tau(cls, n=int, m=int, bond=None, with_units=False,
                     units='angstrom', magnitude=True):
+        """Compute symmetry operation translation :math:`\\tau`
+
+        .. math::
+
+           \\tau = \\frac{M|\\mathbf{T}|}{N}
+
+        Parameters
+        ----------
+        n, m : int
+            Chiral indices defining the nanotube chiral vector
+            :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} +
+            m\\mathbf{a}_{2} = (n, m)`.
+        bond : float, optional
+            distance between nearest neighbor atoms.
+            Must be in units of **Angstroms**.
+        rad2deg : bool, optional
+            If `True`, return angle in degrees
+
+        Returns
+        -------
+        float
+            Symmetry operation translation :math:`\\tau`
+
+        """
         M = Nanotube.compute_M(n=n, m=m)
         N = Nanotube.compute_N(n=n, m=m)
         T = Nanotube.compute_T(n=n, m=m, bond=bond, with_units=with_units,
@@ -1293,6 +1248,25 @@ class Nanotube(object):
 
     @classmethod
     def compute_psi(cls, n=int, m=int):
+        """Compute symmetry operation rotation :math:`\\psi`
+
+        .. math::
+
+           \\psi = \\frac{2\\pi}{N}
+
+        Parameters
+        ----------
+        n, m : int
+            Chiral indices defining the nanotube chiral vector
+            :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} +
+            m\\mathbf{a}_{2} = (n, m)`.
+
+        Returns
+        -------
+        float
+            Symmetry operation rotation :math:`\\psi`
+
+        """
         N = Nanotube.compute_N(n=n, m=m)
         return 2 * np.pi / N
 
@@ -1342,7 +1316,7 @@ class NanotubeBundle(Nanotube):
                  element1='C', element2='C', bond=CCbond, tube_length=None,
                  vdw_spacing=3.4, bundle_packing=None, bundle_geometry=None,
                  Lx=None, Ly=None, Lz=None, fix_Lz=False, with_units=False,
-                 verbose=False):
+                 units=None, verbose=False):
 
         if tube_length is not None and Lz is None:
             Lz = tube_length
@@ -1351,7 +1325,7 @@ class NanotubeBundle(Nanotube):
             n=n, m=m, nx=nx, ny=ny, nz=nz,
             element1=element1, element2=element2,
             bond=bond, Lx=Lx, Ly=Ly, Lz=Lz, fix_Lz=fix_Lz,
-            with_units=with_units, verbose=verbose)
+            with_units=with_units, units=units, verbose=verbose)
 
         self._vdw_spacing = vdw_spacing
         self._bundle_packing = bundle_packing
