@@ -20,11 +20,76 @@ from ..chemistry import Atom, Atoms
 from ..tools import get_fpath
 
 from ._structure_data import StructureReader, StructureWriter, \
-    StructureConverter, StructureSpecs, StructureDataError, \
+    StructureConverter, StructureFormat, StructureDataError, \
     default_comment_line
 
-__all__ = ['DATAReader', 'DATAWriter', 'DATA2XYZConverter',
-           'LAMMPSDATA', 'LAMMPSDATASpecs', 'LAMMPSDATAError']
+__all__ = ['DATAData', 'DATAReader', 'DATAWriter', 'DATA2XYZConverter',
+           'DATAFormat', 'DATAError', 'LAMMPSDATA', 'atom_style_map']
+
+
+atom_style_map = {}
+atom_style_map['angle'] = \
+    ['atom-ID', 'molecule-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['atomic'] = \
+    ['atom-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['body'] = \
+    ['atom-ID', 'atom-type', 'bodyflag', 'mass',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['bond'] = \
+    ['atom-ID', 'molecule-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['charge'] = \
+    ['atom-ID', 'atom-type', 'q', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['dipole'] = \
+    ['atom-ID', 'atom-type', 'q', 'x', 'y', 'z',
+     'mux', 'muy', 'muz', 'nx', 'ny', 'nz']
+
+atom_style_map['electron'] = \
+    ['atom-ID', 'atom-type', 'q', 'spin', 'eradius',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['ellipsoid'] = \
+    ['atom-ID', 'atom-type', 'ellipsoidflag', 'density',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['full'] = \
+    ['atom-ID', 'molecule-ID', 'atom-type', 'q',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['line'] = \
+    ['atom-ID', 'molecule-ID', 'atom-type', 'lineflag', 'density',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['meso'] = \
+    ['atom-ID', 'atom-type', 'rho', 'e', 'cv',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['molecular'] = \
+    ['atom-ID', 'molecule-ID', 'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['peri'] = \
+    ['atom-ID', 'atom-type', 'volume', 'density',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['sphere'] = \
+    ['atom-ID', 'atom-type', 'diameter', 'density',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['template'] = \
+    ['atom-ID', 'molecule-ID', 'template-index', 'template-atom',
+     'atom-type', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['tri'] = \
+    ['atom-ID', 'molecule-ID', 'atom-type', 'triangleflag', 'density',
+     'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+atom_style_map['wavepacket'] = \
+    ['atom-ID', 'atom-type', 'charge', 'spin', 'eradius', 'etag',
+     'cs_re', 'cs_im', 'x', 'y', 'z', 'nx', 'ny', 'nz']
 
 
 class DATAReader(StructureReader):
@@ -40,11 +105,11 @@ class DATAReader(StructureReader):
     def __init__(self, fname=None, atom_style='full'):
         super(DATAReader, self).__init__(fname=fname)
 
-        data_specs = LAMMPSDATASpecs(atom_style=atom_style)
-        self._data_headers = data_specs.properties['headers']
-        self._data_sections = data_specs.properties['sections']
-        self._section_properties = data_specs.section_properties
-        self._section_syntax_dict = data_specs.section_syntax_dict
+        data_format = DATAFormat(atom_style=atom_style)
+        self._data_headers = data_format.properties['headers']
+        self._data_sections = data_format.properties['sections']
+        self._section_properties = data_format.section_properties
+        self._section_syntax_dict = data_format.section_syntax_dict
 
         self._headers = {}
         self._sections = {}
@@ -55,12 +120,12 @@ class DATAReader(StructureReader):
 
     @property
     def headers(self):
-        """DATA file headers."""
+        """LAMMPS DATA file headers."""
         return self._headers
 
     @property
     def sections(self):
-        """DATA file sections."""
+        """LAMMPS DATA file sections."""
         return self._sections
 
     @property
@@ -435,7 +500,7 @@ class DATA2XYZConverter(StructureConverter):
             return XYZReader(fname=self._xyzfile)
 
 
-class LAMMPSDATA(DATAReader):
+class DATAData(DATAReader):
     """Class for reading and writing structure data in LAMMPS data format.
 
     Parameters
@@ -444,7 +509,7 @@ class LAMMPSDATA(DATAReader):
 
     """
     def __init__(self, fname=None):
-        super(LAMMPSDATA, self).__init__(fname=fname)
+        super(DATAData, self).__init__(fname=fname)
 
     def delete(self, key):
         pass
@@ -506,7 +571,7 @@ class LAMMPSDATA(DATAReader):
                     colidx = int(colindex)
             except (KeyError, TypeError, ValueError) as e:
                 print(e)
-                raise LAMMPSDATAError('replace called with invalid arguments')
+                raise DATAError('replace called with invalid arguments')
         atom_attr = self._section_syntax_dict[section_key][colidx]
         attr_dtype = \
             self._section_properties[section_key][atom_attr]['dtype']
@@ -545,8 +610,14 @@ class LAMMPSDATA(DATAReader):
         except (TypeError, ValueError) as e:
             print(e)
 
+    @classmethod
+    def format_spec(cls, atom_style='full'):
+        return DATAFormat(atom_style=atom_style)
 
-class LAMMPSDATAError(StructureDataError):
+LAMMPSDATA = DATAData
+
+
+class DATAError(StructureDataError):
     """Exception raised for failed method calls.
 
     Parameters
@@ -562,7 +633,7 @@ class LAMMPSDATAError(StructureDataError):
         return repr(self.msg)
 
 
-class LAMMPSDATASpecs(StructureSpecs):
+class DATAFormat(StructureFormat):
     """Class defining the structure file format for LAMMPS data.
 
     Parameters
@@ -572,14 +643,77 @@ class LAMMPSDATASpecs(StructureSpecs):
 
     """
     def __init__(self, atom_style='full'):
-        super(LAMMPSDATASpecs, self).__init__()
+        super(DATAFormat, self).__init__()
         self._section_properties = OrderedDict()
 
         atoms_section_syntax = {}
-        atoms_section_syntax['full'] = ['atomID', 'moleculeID', 'atomtype',
-                                        'q', 'x', 'y', 'z', 'nx', 'ny', 'nz']
-        atoms_section_syntax['atomic'] = ['atomID', 'moleculeID', 'atomtype',
-                                          'x', 'y', 'z', 'nx', 'ny', 'nz']
+        atoms_section_syntax['angle'] = \
+            ['atomID', 'moleculeID', 'atomtype',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['atomic'] = \
+            ['atomID', 'atomtype', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['body'] = \
+            ['atomID', 'atomtype', 'bodyflag', 'mass',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['bond'] = \
+            ['atomID', 'moleculeID', 'atomtype',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['charge'] = \
+            ['atomID', 'atomtype', 'q',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['dipole'] = \
+            ['atomID', 'atomtype', 'q', 'x', 'y', 'z',
+             'mux', 'muy', 'muz', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['electron'] = \
+            ['atomID', 'atomtype', 'q', 'spin', 'eradius', 'x', 'y', 'z',
+             'nx', 'ny', 'nz']
+
+        atoms_section_syntax['ellipsoid'] = \
+            ['atomID', 'atomtype', 'ellipsoidflag', 'density',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['full'] = \
+            ['atomID', 'moleculeID', 'atomtype', 'q',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['line'] = \
+            ['atomID', 'moleculeID', 'atomtype', 'lineflag', 'density',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['meso'] = \
+            ['atomID', 'atomtype', 'rho', 'e', 'cv',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['molecular'] = \
+            ['atomID', 'moleculeID', 'atomtype',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['peri'] = \
+            ['atomID', 'atomtype', 'volume', 'density',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['sphere'] = \
+            ['atomID', 'atomtype', 'diameter', 'density',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['template'] = \
+            ['atomID', 'moleculeID', 'template-index', 'template-atom',
+             'atomtype', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['tri'] = \
+            ['atomID', 'moleculeID', 'atomtype', 'triangleflag', 'density',
+             'x', 'y', 'z', 'nx', 'ny', 'nz']
+
+        atoms_section_syntax['wavepacket'] = \
+            ['atomID', 'atomtype', 'charge', 'spin', 'eradius', 'etag',
+             'cs_re', 'cs_im', 'x', 'y', 'z', 'nx', 'ny', 'nz']
+
         velocities_section_syntax = {}
         velocities_section_syntax['full'] = ['atomID', 'vx', 'vy', 'vz']
 
