@@ -26,7 +26,7 @@ __all__ = ['StructureData',
            'StructureReader',
            'StructureWriter',
            'StructureConverter',
-           'StructureSpecs',
+           'StructureFormat',
            'StructureDataError',
            'StructureReaderError',
            'StructureWriterError',
@@ -162,9 +162,8 @@ class StructureConverter(object):
                                    'to implement the `convert` method.')
 
 
-class StructureSpecs(object):
-    """Base class defining common properties for structure formats."""
-
+class StructureFormat(object):
+    """Base class for containing structure format properties"""
     def __init__(self):
         self._properties = OrderedDict()
 
@@ -174,6 +173,13 @@ class StructureSpecs(object):
         return self._properties
 
 
+class StructureFormatter(object):
+    """Base class for wrapping `Atom` attributes into a formatted string."""
+
+    def format(self):
+        pass
+
+
 class StructureDataError(Exception):
     """Base class for `StructureData` exceptions."""
     pass
